import semverMatch from "semver-match";
import { getPackages } from "@monorepo-utils/package-utils";
export const plugin = (options) => {
    // getPackages support "workspaces" and lerna.json
    const monorepoPackages = getPackages(options.rootDir);
    return {
        supports() {
            return monorepoPackages.length > 0;
        },
        getAllPackages() {
            return monorepoPackages;
        },
        getDependencies(packageJSON) {
            var _a, _b;
            const dependencies = Object.entries((_a = packageJSON.dependencies) !== null && _a !== void 0 ? _a : {});
            const devDependencies = Object.entries((_b = packageJSON.devDependencies) !== null && _b !== void 0 ? _b : {});
            return [...dependencies, ...devDependencies].map((dep) => {
                return {
                    name: dep[0],
                    version: dep[1]
                };
            });
        },
        resolve({ name, version }) {
            const matchPkg = monorepoPackages.find((info) => {
                if (info.packageJSON.name !== name)
                    return false;
                if (version.startsWith("workspace:"))
                    return true;
                return !!semverMatch(version, [info.packageJSON.version]);
            });
            if (!matchPkg) {
                return null;
            }
            return matchPkg.location;
        }
    };
};
//# sourceMappingURL=workspaces.js.map